@@ -37,7 +37,13 @@
 	'formatBlock': 'Estilo de párrafo',
 	'fontSize': 'Tamaño de font',
 	'fontName': 'Nombre de font',
+	'tabIndent': 'Sangría de tabulador',
+	"fullScreen": "Conmutar pantalla completa",
+	"viewSource": "Ver fuente HTML",
+	"print": "Imprimir",
+	"newPage": "Nueva página",
 	/* Error messages */
-	'systemShortcutFF': 'La acción "${0}" sólo está disponible en Mozilla Firefox mediante un atajo de teclado. Utilice ${1}.',
-	'ctrlKey':'Control+${0}'
+	'systemShortcut': 'La acción "${0}" sólo está disponible en su navegador mediante un atajo de teclado. Utilice ${1}.',
+	'ctrlKey':'control+${0}'
 })
+
