@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,38 +15,42 @@
  * @category   Zend
  * @package    Zend_Date
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2006 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: DateObjectTest.php 8542 2008-03-04 20:40:52Z darby $
+ * @version    $Id$
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * Zend_Date
  */
 require_once 'Zend/Date.php';
 
-
 /**
+ * @category   Zend
  * @package    Zend_Date
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Date
  */
 class Zend_Date_DateObjectTest extends PHPUnit_Framework_TestCase
 {
 
     public function setUp()
     {
+        $this->originalTimezone = date_default_timezone_get();
         date_default_timezone_set('Europe/Paris');
         require_once 'Zend/Cache.php';
-        $cache = Zend_Cache::factory('Core', 'File',
+        $this->_cache = Zend_Cache::factory('Core', 'File',
                  array('lifetime' => 120, 'automatic_serialization' => true),
                  array('cache_dir' => dirname(__FILE__) . '/../_files/'));
-        Zend_Date_DateObjectTestHelper::setOptions(array('cache' => $cache));
+        Zend_Date_DateObjectTestHelper::setOptions(array('cache' => $this->_cache));
+    }
+
+    public function tearDown()
+    {
+        date_default_timezone_set($this->originalTimezone);
+        $this->_cache->clean(Zend_Cache::CLEANING_MODE_ALL);
     }
 
     /**
@@ -391,8 +394,8 @@ class Zend_Date_DateObjectTest extends PHPUnit_Framework_TestCase
         $this->assertSame(           '0', $date->date('U',0          ));
         $this->assertSame(           '0', $date->date('U',0,false    ));
         $this->assertSame(           '0', $date->date('U',0,true     ));
-        $this->assertSame(  '6900007200', $date->date('U',6900000000 ));
-        $this->assertSame( '-6999996400', $date->date('U',-7000000000));
+        $this->assertSame(  '6900000000', $date->date('U',6900000000 ));
+        $this->assertSame( '-7000000000', $date->date('U',-7000000000));
         $this->assertSame(          '06', $date->date('d',-7000000000));
         $this->assertSame(         'Wed', $date->date('D',-7000000000));
         $this->assertSame(           '6', $date->date('j',-7000000000));
@@ -427,9 +430,9 @@ class Zend_Date_DateObjectTest extends PHPUnit_Framework_TestCase
         $this->assertSame(      '+01:00', $date->date('P',-7000000000));
         $this->assertSame(         'CET', $date->date('T',-7000000000));
         $this->assertSame(        '3600', $date->date('Z',-7000000000));
-        $this->assertSame(       '1748-03-06T12:33:20+0100', $date->date('c',-7000000000));
+        $this->assertSame('1748-03-06T12:33:20+01:00', $date->date('c',-7000000000));
         $this->assertSame('Wed, 06 Mar 1748 12:33:20 +0100', $date->date('r',-7000000000));
-        $this->assertSame( '-6999996400', $date->date('U'    ,-7000000000 ));
+        $this->assertSame( '-7000000000', $date->date('U'    ,-7000000000 ));
         $this->assertSame(           'H', $date->date('\\H'  ,-7000000000 ));
         $this->assertSame(           '.', $date->date('.'    ,-7000000000 ));
         $this->assertSame(    '12:33:20', $date->date('H:i:s',-7000000000 ));
@@ -492,10 +495,10 @@ class Zend_Date_DateObjectTest extends PHPUnit_Framework_TestCase
         $date = new Zend_Date_DateObjectTestHelper(0);
 
         date_default_timezone_set('Europe/Vienna');
-        $this->assertTrue($date->setTimezone('Indian/Maldives'));
+        $date->setTimezone('Indian/Maldives');
         $this->assertSame('Indian/Maldives', $date->getTimezone());
         try {
-            $this->assertFalse($date->setTimezone('Unknown'));
+            $date->setTimezone('Unknown');
             // without new phpdate false timezones do not throw an exception !
             // known and expected behaviour
             if (function_exists('timezone_open')) {
@@ -506,7 +509,7 @@ class Zend_Date_DateObjectTest extends PHPUnit_Framework_TestCase
             $this->assertSame('Unknown', $e->getOperand());
         }
         $this->assertSame('Indian/Maldives', $date->getTimezone());
-        $this->assertTrue($date->setTimezone());
+        $date->setTimezone();
         $this->assertSame('Europe/Vienna', $date->getTimezone());
     }
 
@@ -536,6 +539,24 @@ class Zend_Date_DateObjectTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(($diff < 2), "Zend_Date_DateObject->_getTime() returned a significantly "
             . "different timestamp than expected: $diff seconds");
     }
+    
+    /**
+     * Test for RFC 2822's Obsolete Date and Time (paragraph 4.3)
+     * 
+     * @see ZF-11296
+     */
+    public function test_obsRfc2822()
+    {
+        $date = new Zend_Date();
+        /* Obsolete timezones */
+        $this->assertTrue($date->set("Mon, 15 Aug 2005 15:52:01 +0000", Zend_Date::RFC_2822) instanceof Zend_Date);
+        $this->assertTrue($date->set("Mon, 15 Aug 2005 15:52:01 UT", Zend_Date::RFC_2822) instanceof Zend_Date);
+        $this->assertTrue($date->set("Mon, 15 Aug 2005 15:52:01 GMT", Zend_Date::RFC_2822) instanceof Zend_Date);
+        $this->assertTrue($date->set("Mon, 15 Aug 2005 15:52:01 EST", Zend_Date::RFC_2822) instanceof Zend_Date);
+        $this->assertTrue($date->set("Mon, 15 Aug 2005 15:52:01 I", Zend_Date::RFC_2822) instanceof Zend_Date);
+        $this->assertTrue($date->set("Mon, 15 Aug 2005 15:52:01 Z", Zend_Date::RFC_2822) instanceof Zend_Date);
+    }
+    
 }
 
 class Zend_Date_DateObjectTestHelper extends Zend_Date
@@ -590,4 +611,4 @@ class Zend_Date_DateObjectTestHelper extends Zend_Date
     {
         return parent::_getTime($sync);
     }
-}
\ No newline at end of file
+}
