@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StreamTest.php 24593 2012-01-05 20:35:02Z matthew $
+ * @version    $Id$
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -34,7 +34,7 @@ require_once 'Zend/Log/Writer/Stream.php';
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Log
  */
@@ -53,7 +53,7 @@ class Zend_Log_Writer_StreamTest extends PHPUnit_Framework_TestCase
             new Zend_Log_Writer_Stream($resource);
             $this->fail();
         } catch (Exception $e) {
-            $this->assertType('Zend_Log_Exception', $e);
+            $this->assertTrue($e instanceof Zend_Log_Exception);
             $this->assertRegExp('/not a stream/i', $e->getMessage());
         }
         xml_parser_free($resource);
@@ -77,7 +77,7 @@ class Zend_Log_Writer_StreamTest extends PHPUnit_Framework_TestCase
             new Zend_Log_Writer_Stream($stream, 'w+');
             $this->fail();
         } catch (Exception $e) {
-            $this->assertType('Zend_Log_Exception', $e);
+            $this->assertTrue($e instanceof Zend_Log_Exception);
             $this->assertRegExp('/existing stream/i', $e->getMessage());
         }
     }
@@ -88,7 +88,7 @@ class Zend_Log_Writer_StreamTest extends PHPUnit_Framework_TestCase
             new Zend_Log_Writer_Stream('');
             $this->fail();
         } catch (Exception $e) {
-            $this->assertType('Zend_Log_Exception', $e);
+            $this->assertTrue($e instanceof Zend_Log_Exception);
             $this->assertRegExp('/cannot be opened/i', $e->getMessage());
         }
     }
@@ -118,7 +118,7 @@ class Zend_Log_Writer_StreamTest extends PHPUnit_Framework_TestCase
             $writer->write(array('message' => 'foo'));
             $this->fail();
         } catch (Exception $e) {
-            $this->assertType('Zend_Log_Exception', $e);
+            $this->assertTrue($e instanceof Zend_Log_Exception);
             $this->assertRegExp('/unable to write/i', $e->getMessage());
         }
     }
@@ -134,7 +134,7 @@ class Zend_Log_Writer_StreamTest extends PHPUnit_Framework_TestCase
             $writer->write(array('message' => 'this write should fail'));
             $this->fail();
         } catch (Exception $e) {
-            $this->assertType('Zend_Log_Exception', $e);
+            $this->assertTrue($e instanceof Zend_Log_Exception);
             $this->assertRegExp('/unable to write/i', $e->getMessage());
         }
     }
@@ -187,4 +187,4 @@ class Zend_Log_Writer_StreamTest extends PHPUnit_Framework_TestCase
 
 if (PHPUnit_MAIN_METHOD == 'Zend_Log_Writer_StreamTest::main') {
     Zend_Log_Writer_StreamTest::main();
-}
\ No newline at end of file
+}
